@@ -2,10 +2,11 @@
 #'
 #' Checks if valid parameter names.
 #'
-#' The character vector must consist of unique,
-#' non-missing values that start with an alpha
+#' The character vector must consist of values that start with an alpha
 #' and only include alphanumeric characters and '_' or '.'.
 #'
+#' Missing values and duplicates are permitted.
+#'
 #' @inheritParams params
 #' @inheritParams chk::chk_flag
 #' @return
@@ -25,9 +26,7 @@ chk_pars <- function(x, x_name = NULL) {
   if (is.null(x_name)) x_name <- deparse_backtick_chk(substitute(x))
 
   chk_s3_class(x, "character", x_name = x_name)
-  chk_not_any_na(x, x_name = x_name)
-  chk_unique(x, x_name = x_name)
-  chk_match(x, p0("^[[:alpha:]][[:alnum:]._]*$"), x_name = x_name)
+  chk_match(x, p0("^", par_pattern(), "$"), x_name = x_name)
 }
 
 #' @describeIn chk_pars Validate Parameter Names
@@ -38,7 +37,5 @@ chk_pars <- function(x, x_name = NULL) {
 #' vld_pars(c("x[1]", "a1", "a1", "._0"))
 vld_pars <- function(x) {
   vld_s3_class(x, "character") &&
-    vld_not_any_na(x) &&
-    vld_unique(x) &&
-    vld_match(x, p0("^[[:alpha:]][[:alnum:]._]*$"))
+    vld_match(x, p0("^", par_pattern(), "$"))
 }
