@@ -9,11 +9,15 @@
 #' xtr_sd(1:10)
 xtr_sd <- function(x, na_rm = FALSE) {
   chk_numeric(x)
-  if(anyNA(x)) {
-    if(vld_false(na_rm)) return(NA_real_)
+  if (anyNA(x)) {
+    if (vld_false(na_rm)) {
+      return(NA_real_)
+    }
     x <- as.vector(x)
     x <- x[!is.na(x)]
   }
-  if(!length(x)) return(NA_real_)
+  if (!length(x)) {
+    return(NA_real_)
+  }
   stats::sd(x)
 }
