@@ -13,8 +13,10 @@
 zscore <- function(x, na_rm = FALSE) {
   chk_numeric(x)
 
-  if(anyNA(x)) {
-    if(vld_false(na_rm)) return(NA_real_)
+  if (anyNA(x)) {
+    if (vld_false(na_rm)) {
+      return(NA_real_)
+    }
     x <- as.vector(x)
     x <- x[!is.na(x)]
   }
